@@ -9,6 +9,9 @@ https://github.com/tiddlyweb/chrjs/raw/master/main.js
 // * ensure all routes are supported
 // * documentation
 
+/*jslint nomen: false */
+/*global jQuery, tiddlyweb */
+
 (function($) {
 
 tiddlyweb = {
@@ -45,7 +48,7 @@ $.extend(tiddlyweb.Resource.prototype, {
 	get: function(callback, errback, filters) {
 		var uri = this.route();
 		if(filters) {
-			var separator = uri.indexOf("?") == -1 ? "?" : ";";
+			var separator = uri.indexOf("?") === -1 ? "?" : ";";
 			uri += separator + filters;
 		}
 		var self = this;
@@ -67,20 +70,13 @@ $.extend(tiddlyweb.Resource.prototype, {
 	// callback is passed data, status, XHR (cf. jQuery.ajax success)
 	// errback is passed XHR, error, exception, resource (cf. jQuery.ajax error)
 	put: function(callback, errback) {
-		var self = this;
-		var uri = this.route();
-		var data = {};
-		$.each(this.data, function(i, item) {
-			var value = self[item];
-			if(value !== undefined) {
-				data[item] = value;
-			}
-		});
+		var self = this,
+			uri = this.route();
 		var options = {
 			url: uri,
 			type: "PUT",
 			contentType: "application/json",
-			data: $.toJSON(data),
+			data: this.toJSON(),
 			success: function(data, status, xhr) {
 				callback(self, status, xhr);
 			},
@@ -97,8 +93,8 @@ $.extend(tiddlyweb.Resource.prototype, {
 	// callback is passed data, status, XHR (cf. jQuery.ajax success)
 	// errback is passed XHR, error, exception, resource (cf. jQuery.ajax error)
 	"delete": function(callback, errback) {
-		var self = this;
-		var uri = this.route();
+		var self = this,
+			uri = this.route();
 		var options = {
 			url: uri,
 			type: "DELETE",
@@ -114,6 +110,18 @@ $.extend(tiddlyweb.Resource.prototype, {
 		}
 		return $.ajax(options);
 	},
+	// returns the JSON representation of a resource
+	toJSON: function() {
+		var data = {},
+			self = this;
+		$.each(this.data, function(i, item) {
+			var value = self[item];
+			if(value !== undefined) {
+				data[item] = value;
+			}
+		});
+		return $.toJSON(data);
+	},
 	// returns corresponding instance from raw JSON object (if applicable)
 	parse: function(data) {
 		return data;
@@ -140,8 +148,8 @@ $.extend(Container.prototype, {
 		return new TiddlerCollection(this);
 	},
 	parse: function(data) {
-		var type = tiddlyweb._capitalize(this._type);
-		var container = new tiddlyweb[type](this.name, this.host);
+		var type = tiddlyweb._capitalize(this._type),
+			container = new tiddlyweb[type](this.name, this.host);
 		data.policy = new tiddlyweb.Policy(data.policy);
 		return $.extend(container, data);
 	},
@@ -169,8 +177,8 @@ $.extend(TiddlerCollection.prototype, {
 	parse: function(data) {
 		var container = this.container;
 		return $.map(data, function(item, i) {
-			var tiddler = new tiddlyweb.Tiddler(item.title, container);
-			var bag = item.bag;
+			var tiddler = new tiddlyweb.Tiddler(item.title, container),
+				bag = item.bag;
 			tiddler = tiddlyweb.Tiddler.prototype.parse.apply(tiddler, [item]);
 			if(!tiddler.bag && bag) { // XXX: bag always present!?
 				tiddler.bag = new tiddlyweb.Bag(bag, container.host);
@@ -183,16 +191,15 @@ $.extend(TiddlerCollection.prototype, {
 		});
 	},
 	route: function() {
+		var params = this.container;
 		if(this.tiddler) {
 			var container = this.tiddler.bag || this.tiddler.recipe;
-			var params = {
+			params = {
 				_type: container._type,
 				host: container.host,
 				name: container.name,
 				title: this.tiddler.title
 			};
-		} else {
-			params = this.container;
 		}
 		return supplant(tiddlyweb.routes[this._type], params);
 	}
@@ -220,8 +227,8 @@ $.extend(tiddlyweb.Search.prototype, {
 tiddlyweb.Tiddler = function(title, container) {
 	tiddlyweb.Resource.apply(this, ["tiddler", false]);
 	this.title = title;
-	this.bag = container && container._type == "bag" ? container : null;
-	this.recipe = container && container._type == "recipe" ? container : null;
+	this.bag = container && container._type === "bag" ? container : null;
+	this.recipe = container && container._type === "recipe" ? container : null;
 	var self = this;
 	$.each(this.data, function(i, item) {
 		self[item] = undefined; // exposes list of standard attributes for inspectability
@@ -242,8 +249,8 @@ $.extend(tiddlyweb.Tiddler.prototype, {
 		return supplant(tiddlyweb.routes[this._type], params);
 	},
 	parse: function(data) {
-		var tiddler = new tiddlyweb.Tiddler(this.title);
-		var container = this.bag || this.recipe;
+		var tiddler = new tiddlyweb.Tiddler(this.title),
+			container = this.bag || this.recipe;
 		tiddler.bag = new tiddlyweb.Bag(data.bag, container.host);
 		delete data.bag;
 		delete data.recipe;
@@ -259,16 +266,16 @@ $.extend(tiddlyweb.Tiddler.prototype, {
 	data: ["modifier", "tags", "fields", "text", "type"],
 	ajaxSetup: function(options) {
 		var self = this;
-		if(this.etag && (options.type == "PUT" || options.type == "DELETE")) {
+		if(this.etag && (options.type === "PUT" || options.type === "DELETE")) {
 			options.beforeSend = function(xhr) {
 				xhr.setRequestHeader("If-Match", self.etag);
 			};
 		}
-		if(options.type == "PUT") {
+		if(options.type === "PUT") {
 			var callback = options.success;
 			options.success = function(data, status, xhr) {
-				var loc = xhr.getResponseHeader("Location");
-				var etag = xhr.getResponseHeader("Etag");
+				var loc = xhr.getResponseHeader("Location"),
+					etag = xhr.getResponseHeader("Etag");
 				if(loc && etag) {
 					self.etag = etag;
 					if(!self.bag) {
@@ -347,9 +354,9 @@ var supplant = function(str, obj) {
 	return str.replace(/{([^{}]*)}/g, function (a, b) {
 		var r = obj[b];
 		r = typeof r === "string" || typeof r === "number" ? r : a;
-		return $.inArray(b, ["host", "query"]) != -1 ? r : encodeURIComponent(r); // XXX: special-casing
+		return $.inArray(b, ["host", "query"]) !== -1 ? r : encodeURIComponent(r); // XXX: special-casing
 	});
 };
 
-})(jQuery);
+}(jQuery));
 //}}}
